setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # set working directory to current folder

library(BayesFactor)
library(effectsize)
library(tidyverse)

df <- read_csv("main_study_results.csv")[,-1] %>% 
  dplyr::select(-c(Enough_info, More_info, Fair_process, Changes)) %>% 
  mutate_if(is.character, as.factor)

# Confirmatory analyses
## H1a, H2a
anova <- anova(lm(Inf_fairness ~ Explanation * Task_stakes + Contestability + Human_oversight, df))
anova
effectsize::eta_squared(anova) # effect sizes

set.seed(1)
a <- anovaBF(Inf_fairness ~ Explanation * Task_stakes + Human_oversight + Contestability, data = df, whichModels = "bottom")
1/a # BF01 for condition null hypothesis

## H1b, H1c, H1d, H1e, H2b, H2c
anova2 <- anova(lm(Proc_fairness ~ Human_oversight * Task_stakes + Contestability * Task_stakes + Explanation * Contestability + Human_oversight * Contestability, df))
anova2
effectsize::eta_squared(anova2) # effect sizes

b <- anovaBF(Proc_fairness ~ Human_oversight * Task_stakes + Contestability * Task_stakes + Explanation * Contestability + Human_oversight * Contestability, data = df, whichModels = "bottom")
1/b # BF01 for condition null hypothesis

## H3a, H3b, H3c
summary(lm(Ovrl_fairness ~ Inf_fairness * Proc_fairness, df))

# Exploratory analyses
# Manipulation Check
t.test(Manipulation_check_task_stakes ~ Task_stakes, df)
sd(filter(df, Task_stakes != "Low stakes (holiday)")$Manipulation_check_task_stakes)

# Pairwise tests
TukeyHSD(aov(lm(Proc_fairness ~ Contestability, df)))
df %>% group_by(Contestability) %>% summarise(mean(Proc_fairness))

#Effect of AI literacy
anova3 <- anova(lm(Inf_fairness ~ Explanation * Task_stakes * AI_literacy + Contestability * Human_oversight * Task_stakes, df))
anova3
effectsize::eta_squared(anova3) # effect sizes

#IF1 = Thorough, IF2 = Reasonable, IF3 = Tailored, IF4 = Understandable
an_thorough <- anova(lm(Inf_fairness_1 ~ Explanation * Task_stakes* AI_literacy + Contestability * Human_oversight * Task_stakes, df))
an_reason <- anova(lm(Inf_fairness_2 ~ Explanation * Task_stakes* AI_literacy + Contestability * Human_oversight * Task_stakes, df))
an_tailored <- anova(lm(Inf_fairness_3 ~ Explanation * Task_stakes* AI_literacy + Contestability * Human_oversight * Task_stakes, df))
an_underst <- anova(lm(Inf_fairness_4 ~ Explanation * Task_stakes* AI_literacy + Contestability * Human_oversight * Task_stakes, df))
effectsize::eta_squared(an_thorough) # effect sizes
effectsize::eta_squared(an_reason) 
effectsize::eta_squared(an_tailored)
effectsize::eta_squared(an_underst) 


#PF1 = Voice, PF2 = Influence, PF3 = Consistency, PF4 = Lack of bias, PF5 = Adequacy of factors, PF6 = Correctability, PF7 = Ethicality
an_voice <- anova(lm(Proc_fairness_1 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
an_influence <- anova(lm(Proc_fairness_2 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
an_consist <- anova(lm(Proc_fairness_3 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
an_bias <- anova(lm(Proc_fairness_4 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
an_adeq <- anova(lm(Proc_fairness_5 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
an_correct <- anova(lm(Proc_fairness_6 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
an_ethic < -anova(lm(Proc_fairness_7 ~ Explanation * Contestability + Contestability * Task_stakes + Human_oversight * Task_stakes + Contestability * Human_oversight, df))
effectsize::eta_squared(an_voice) #effect sizes
effectsize::eta_squared(an_influence) 
effectsize::eta_squared(an_consist)
effectsize::eta_squared(an_bias) 
effectsize::eta_squared(an_adeq) 
effectsize::eta_squared(an_correct) 
effectsize::eta_squared(an_ethic) 

#Descriptive statistics PF1, PF2
df %>% 
  group_by(Contestability) %>% 
  summarise(Proc_fairness_1_mean = mean(Proc_fairness_1),
            Proc_fairness_1_sd = (sd(Proc_fairness_1)/sqrt(length(Proc_fairness_1))))
df %>% 
  group_by(Contestability) %>% 
  summarise(Proc_fairness_2_mean = mean(Proc_fairness_2),
            Proc_fairness_2_sd = (sd(Proc_fairness_2)/sqrt(length(Proc_fairness_2))))

